@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2006-2014 LOGILAB S.A. (Paris, FRANCE) <contact@logilab.fr>
 # Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014 Vlad Temian <vladtemian@gmail.com>
@@ -7,9 +6,9 @@
 # Copyright (c) 2015 Ionel Cristian Maries <contact@ionelmc.ro>
 # Copyright (c) 2016 Derek Gustafson <degustaf@gmail.com>
 # Copyright (c) 2016 Moises Lopez <moylop260@vauxoo.com>
-# Copyright (c) 2017 Pierre Sassoulas <pierre.sassoulas@cea.fr>
+# Copyright (c) 2017, 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2017, 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017, 2019 Thomas Hisch <t.hisch@gmail.com>
-# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017 Daniel Miller <millerdev@gmail.com>
 # Copyright (c) 2017 Bryce Guinta <bryce.paul.guinta@gmail.com>
 # Copyright (c) 2017 Ville Skyttä <ville.skytta@iki.fi>
@@ -17,16 +16,21 @@
 # Copyright (c) 2018 Jason Owen <jason.a.owen@gmail.com>
 # Copyright (c) 2018 Jace Browning <jacebrowning@gmail.com>
 # Copyright (c) 2018 Reverb C <reverbc@users.noreply.github.com>
-# Copyright (c) 2019-2020 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2019 Hugues <hugues.bruant@affirm.com>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
 # Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
+# Copyright (c) 2020 Frank Harrison <frank@doublethefish.com>
+# Copyright (c) 2020 Matěj Grabovský <mgrabovs@redhat.com>
 # Copyright (c) 2020 Pieter Engelbrecht <pengelbrecht@rems2.com>
 # Copyright (c) 2020 Clément Pit-Claudel <cpitclaudel@users.noreply.github.com>
 # Copyright (c) 2020 Anthony Sottile <asottile@umich.edu>
+# Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Andreas Finkler <andi.finkler@gmail.com>
+# Copyright (c) 2021 chohner <mail@chohner.com>
+# Copyright (c) 2021 Louis Sautier <sautier.louis@gmail.com>
 
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 # pylint: disable=too-many-public-methods
 
@@ -40,20 +44,28 @@ import subprocess
 import sys
 import textwrap
 import warnings
+from copy import copy
 from io import StringIO
 from os.path import abspath, dirname, join
+from pathlib import Path
+from typing import Generator, Optional
 from unittest import mock
+from unittest.mock import patch
 
 import pytest
 
-from pylint.constants import MAIN_CHECKER_NAME
+from pylint import modify_sys_path
+from pylint.constants import MAIN_CHECKER_NAME, MSG_TYPES_STATUS
 from pylint.lint import Run
 from pylint.reporters import JSONReporter
 from pylint.reporters.text import BaseReporter, ColorizedTextReporter, TextReporter
 from pylint.utils import utils
 
 HERE = abspath(dirname(__file__))
-CLEAN_PATH = re.escape(dirname(dirname(__file__)) + "/")
+CLEAN_PATH = re.escape(dirname(dirname(__file__)) + os.path.sep)
+UNNECESSARY_LAMBDA = join(
+    HERE, "functional", "u", "unnecessary", "unnecessary_lambda.py"
+)
 
 
 @contextlib.contextmanager
@@ -125,9 +137,9 @@ class TestRunTC:
             output = out.getvalue()
         else:
             output = None
-        msg = "expected output status %s, got %s" % (code, pylint_code)
+        msg = f"expected output status {code}, got {pylint_code}"
         if output is not None:
-            msg = "%s. Below pylint output: \n%s" % (msg, output)
+            msg = f"{msg}. Below pylint output: \n{output}"
         assert pylint_code == code, msg
 
     @staticmethod
@@ -143,7 +155,8 @@ class TestRunTC:
     @staticmethod
     def _clean_paths(output):
         """Normalize path to the tests directory."""
-        return re.sub(CLEAN_PATH, "", output.replace("\\", "/"), flags=re.MULTILINE)
+        output = re.sub(CLEAN_PATH, "", output, flags=re.MULTILINE)
+        return output.replace("\\", "/")
 
     def _test_output(self, args, expected_output):
         out = StringIO()
@@ -152,6 +165,21 @@ class TestRunTC:
         expected_output = self._clean_paths(expected_output)
         assert expected_output.strip() in actual_output.strip()
 
+    def _test_output_file(self, args, filename, expected_output):
+        """
+        Run Pylint with the ``output`` option set (must be included in
+        the ``args`` passed to this method!) and check the file content afterwards.
+        """
+        out = StringIO()
+        self._run_pylint(args, out=out)
+        cmdline_output = out.getvalue()
+        file_output = self._clean_paths(Path(filename).read_text(encoding="utf-8"))
+        expected_output = self._clean_paths(expected_output)
+        assert (
+            cmdline_output == ""
+        ), "Unexpected output to stdout/stderr while output option was set"
+        assert expected_output.strip() in file_output.strip()
+
     def test_pkginfo(self):
         """Make pylint check itself."""
         self._runtest(["pylint.__pkginfo__"], reporter=TextReporter(StringIO()), code=0)
@@ -202,9 +230,9 @@ class TestRunTC:
         output = out.getvalue()
         # Get rid of the pesky messages that pylint emits if the
         # configuration file is not found.
-        pattern = r"\[{}".format(MAIN_CHECKER_NAME.upper())
+        pattern = rf"\[{MAIN_CHECKER_NAME.upper()}"
         master = re.search(pattern, output)
-        assert master is not None, "{} not found in {}".format(pattern, output)
+        assert master is not None, f"{pattern} not found in {output}"
         out = StringIO(output[master.start() :])
         parser = configparser.RawConfigParser()
         parser.read_file(out)
@@ -217,11 +245,8 @@ class TestRunTC:
         output = out.getvalue()
         assert "profile" not in output
 
-    def test_inexisting_rcfile(self):
-        out = StringIO()
-        with pytest.raises(IOError) as excinfo:
-            self._run_pylint(["--rcfile=/tmp/norcfile.txt"], out=out)
-        assert str(excinfo.value) == "The config file /tmp/norcfile.txt doesn't exist!"
+    def test_nonexistent_config_file(self):
+        self._runtest(["--rcfile=/tmp/this_file_does_not_exist"], code=32)
 
     def test_help_message_option(self):
         self._runtest(["--help-msg", "W0101"], code=0)
@@ -233,8 +258,7 @@ class TestRunTC:
         self._runtest([], code=32)
 
     def test_no_out_encoding(self):
-        """test redirection of stdout with non ascii caracters
-        """
+        """test redirection of stdout with non ascii caracters"""
         # This test reproduces bug #48066 ; it happens when stdout is redirected
         # through '>' : the sys.stdout.encoding becomes then None, and if the
         # output contains non ascii, pylint will crash
@@ -247,14 +271,34 @@ class TestRunTC:
         )
 
     def test_parallel_execution(self):
+        out = StringIO()
         self._runtest(
             [
                 "-j 2",
                 join(HERE, "functional", "a", "arguments.py"),
-                join(HERE, "functional", "a", "arguments.py"),
             ],
-            code=2,
+            out=out,
+            # We expect similarities to fail and an error
+            code=MSG_TYPES_STATUS["E"],
         )
+        assert (
+            "Unexpected keyword argument 'fourth' in function call"
+            in out.getvalue().strip()
+        )
+
+    def test_parallel_execution_bug_2674(self):
+        """Tests that disabling absolute imports works the same in -j1/j2"""
+        expected_ret_code = 0  # we are disabling the check, should pass
+        for jobs in (1, 2):
+            self._runtest(
+                [
+                    "--py3k",
+                    "--disable=no-absolute-import",
+                    "-j %d" % jobs,
+                    join(HERE, "input", "no_absolute_import.py"),
+                ],
+                code=expected_ret_code,
+            )
 
     def test_parallel_execution_missing_arguments(self):
         self._runtest(["-j 2", "not_here", "not_here_too"], code=1)
@@ -262,17 +306,11 @@ class TestRunTC:
     def test_py3k_option(self):
         # Test that --py3k flag works.
         rc_code = 0
-        self._runtest(
-            [join(HERE, "functional", "u", "unnecessary_lambda.py"), "--py3k"],
-            code=rc_code,
-        )
+        self._runtest([UNNECESSARY_LAMBDA, "--py3k"], code=rc_code)
 
     def test_py3k_jobs_option(self):
         rc_code = 0
-        self._runtest(
-            [join(HERE, "functional", "u", "unnecessary_lambda.py"), "--py3k", "-j 2"],
-            code=rc_code,
-        )
+        self._runtest([UNNECESSARY_LAMBDA, "--py3k", "-j 2"], code=rc_code)
 
     def test_abbreviations_are_not_supported(self):
         expected = "no such option: --load-plugin"
@@ -281,14 +319,12 @@ class TestRunTC:
     def test_enable_all_works(self):
         module = join(HERE, "data", "clientmodule_test.py")
         expected = textwrap.dedent(
-            """
+            f"""
         ************* Module data.clientmodule_test
-        {0}:10:8: W0612: Unused variable 'local_variable' (unused-variable)
-        {0}:18:4: C0116: Missing function or method docstring (missing-function-docstring)
-        {0}:22:0: C0115: Missing class docstring (missing-class-docstring)
-        """.format(
-                module
-            )
+        {module}:10:8: W0612: Unused variable 'local_variable' (unused-variable)
+        {module}:18:4: C0116: Missing function or method docstring (missing-function-docstring)
+        {module}:22:0: C0115: Missing class docstring (missing-class-docstring)
+        """
         )
         self._test_output(
             [module, "--disable=all", "--enable=all", "-rn"], expected_output=expected
@@ -298,12 +334,10 @@ class TestRunTC:
         module1 = join(HERE, "regrtest_data", "import_something.py")
         module2 = join(HERE, "regrtest_data", "wrong_import_position.py")
         expected_output = textwrap.dedent(
-            """
+            f"""
         ************* Module wrong_import_position
-        {}:11:0: C0413: Import "import os" should be placed at the top of the module (wrong-import-position)
-        """.format(
-                module2
-            )
+        {module2}:11:0: C0413: Import "import os" should be placed at the top of the module (wrong-import-position)
+        """
         )
         args = [
             module2,
@@ -420,12 +454,10 @@ class TestRunTC:
     def test_error_mode_shows_no_score(self):
         module = join(HERE, "regrtest_data", "application_crash.py")
         expected_output = textwrap.dedent(
-            """
+            f"""
         ************* Module application_crash
-        {}:1:6: E0602: Undefined variable 'something_undefined' (undefined-variable)
-        """.format(
-                module
-            )
+        {module}:1:6: E0602: Undefined variable 'something_undefined' (undefined-variable)
+        """
         )
         self._test_output([module, "-E"], expected_output=expected_output)
 
@@ -480,14 +512,12 @@ class TestRunTC:
         path = join(HERE, "regrtest_data", "test_pylintrc_comments.py")
         config_path = join(HERE, "regrtest_data", "comments_pylintrc")
         expected = textwrap.dedent(
-            """
+            f"""
         ************* Module test_pylintrc_comments
-        {0}:2:0: W0311: Bad indentation. Found 1 spaces, expected 4 (bad-indentation)
-        {0}:1:0: C0114: Missing module docstring (missing-module-docstring)
-        {0}:1:0: C0116: Missing function or method docstring (missing-function-docstring)
-        """.format(
-                path
-            )
+        {path}:2:0: W0311: Bad indentation. Found 1 spaces, expected 4 (bad-indentation)
+        {path}:1:0: C0114: Missing module docstring (missing-module-docstring)
+        {path}:1:0: C0116: Missing function or method docstring (missing-function-docstring)
+        """
         )
         self._test_output(
             [path, "--rcfile=%s" % config_path, "-rn"], expected_output=expected
@@ -501,11 +531,9 @@ class TestRunTC:
     def test_getdefaultencoding_crashes_with_lc_ctype_utf8(self):
         module = join(HERE, "regrtest_data", "application_crash.py")
         expected_output = textwrap.dedent(
-            """
-        {}:1:6: E0602: Undefined variable 'something_undefined' (undefined-variable)
-        """.format(
-                module
-            )
+            f"""
+        {module}:1:6: E0602: Undefined variable 'something_undefined' (undefined-variable)
+        """
         )
         with _configure_lc_ctype("UTF-8"):
             self._test_output([module, "-E"], expected_output=expected_output)
@@ -538,10 +566,10 @@ class TestRunTC:
         ],
     )
     def test_stdin(self, input_path, module, expected_path):
-        expected_output = (
-            "************* Module {module}\n"
-            "{path}:1:0: W0611: Unused import os (unused-import)\n\n"
-        ).format(path=expected_path, module=module)
+        expected_output = f"""************* Module {module}
+{expected_path}:1:0: W0611: Unused import os (unused-import)
+
+"""
 
         with mock.patch(
             "pylint.lint.pylinter._read_stdin", return_value="import os\n"
@@ -642,9 +670,9 @@ class TestRunTC:
         self._runtest(
             [
                 "--fail-under",
-                "5",
+                "-10",
                 "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+                join(HERE, "regrtest_data", "fail_under_plus7_5.py"),
             ],
             code=0,
         )
@@ -653,34 +681,25 @@ class TestRunTC:
                 "--fail-under",
                 "6",
                 "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+                join(HERE, "regrtest_data", "fail_under_plus7_5.py"),
             ],
             code=0,
         )
         self._runtest(
             [
                 "--fail-under",
-                "5.5",
+                "7.5",
                 "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+                join(HERE, "regrtest_data", "fail_under_plus7_5.py"),
             ],
             code=0,
         )
         self._runtest(
             [
                 "--fail-under",
-                "7",
+                "7.6",
                 "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_plus6.py"),
-            ],
-            code=16,
-        )
-        self._runtest(
-            [
-                "--fail-under",
-                "6.7",
-                "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+                join(HERE, "regrtest_data", "fail_under_plus7_5.py"),
             ],
             code=16,
         )
@@ -688,21 +707,174 @@ class TestRunTC:
         self._runtest(
             [
                 "--fail-under",
-                "0",
+                "-11",
                 "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_minus6.py"),
+                join(HERE, "regrtest_data", "fail_under_minus10.py"),
             ],
-            code=22,
+            code=0,
         )
         self._runtest(
             [
                 "--fail-under",
                 "-10",
                 "--enable=all",
-                join(HERE, "regrtest_data", "fail_under_plus6.py"),
+                join(HERE, "regrtest_data", "fail_under_minus10.py"),
             ],
             code=0,
         )
+        self._runtest(
+            [
+                "--fail-under",
+                "-9",
+                "--enable=all",
+                join(HERE, "regrtest_data", "fail_under_minus10.py"),
+            ],
+            code=22,
+        )
+        self._runtest(
+            [
+                "--fail-under",
+                "-5",
+                "--enable=all",
+                join(HERE, "regrtest_data", "fail_under_minus10.py"),
+            ],
+            code=22,
+        )
+
+    @staticmethod
+    def test_modify_sys_path() -> None:
+        @contextlib.contextmanager
+        def test_sys_path() -> Generator[None, None, None]:
+            original_path = sys.path
+            try:
+                yield
+            finally:
+                sys.path = original_path
+
+        @contextlib.contextmanager
+        def test_environ_pythonpath(
+            new_pythonpath: Optional[str],
+        ) -> Generator[None, None, None]:
+            original_pythonpath = os.environ.get("PYTHONPATH")
+            if new_pythonpath:
+                os.environ["PYTHONPATH"] = new_pythonpath
+            elif new_pythonpath is None and original_pythonpath is not None:
+                # If new_pythonpath is None, make sure to delete PYTHONPATH if present
+                del os.environ["PYTHONPATH"]
+            try:
+                yield
+            finally:
+                if original_pythonpath:
+                    os.environ["PYTHONPATH"] = original_pythonpath
+                elif new_pythonpath is not None:
+                    # Only delete PYTHONPATH if new_pythonpath wasn't None
+                    del os.environ["PYTHONPATH"]
+
+        with test_sys_path(), patch("os.getcwd") as mock_getcwd:
+            cwd = "/tmp/pytest-of-root/pytest-0/test_do_not_import_files_from_0"
+            mock_getcwd.return_value = cwd
+            default_paths = [
+                "/usr/local/lib/python39.zip",
+                "/usr/local/lib/python3.9",
+                "/usr/local/lib/python3.9/lib-dynload",
+                "/usr/local/lib/python3.9/site-packages",
+            ]
+
+            paths = [
+                cwd,
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(None):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+
+            paths = [
+                cwd,
+                cwd,
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath("."):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+
+            paths = [
+                cwd,
+                "/custom_pythonpath",
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath("/custom_pythonpath"):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+
+            paths = [
+                cwd,
+                "/custom_pythonpath",
+                cwd,
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath("/custom_pythonpath:"):
+                modify_sys_path()
+            assert sys.path == [paths[1]] + paths[3:]
+
+            paths = [
+                "",
+                cwd,
+                "/custom_pythonpath",
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(":/custom_pythonpath"):
+                modify_sys_path()
+            assert sys.path == paths[2:]
+
+            paths = [
+                cwd,
+                cwd,
+                "/custom_pythonpath",
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(":/custom_pythonpath:"):
+                modify_sys_path()
+            assert sys.path == paths[2:]
+
+            paths = [
+                cwd,
+                cwd,
+                *default_paths,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(":."):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(f":{cwd}"):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+
+            sys.path = copy(paths)
+            with test_environ_pythonpath(".:"):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(f"{cwd}:"):
+                modify_sys_path()
+            assert sys.path == paths[1:]
+
+            paths = [
+                "",
+                cwd,
+                *default_paths,
+                cwd,
+            ]
+            sys.path = copy(paths)
+            with test_environ_pythonpath(cwd):
+                modify_sys_path()
+            assert sys.path == paths[1:]
 
     @staticmethod
     def test_do_not_import_files_from_local_directory(tmpdir):
@@ -752,6 +924,65 @@ class TestRunTC:
                 cwd=str(tmpdir),
             )
 
+    @staticmethod
+    def test_do_not_import_files_from_local_directory_with_pythonpath(tmpdir):
+        p_astroid = tmpdir / "astroid.py"
+        p_astroid.write("'Docstring'\nimport completely_unknown\n")
+        p_hmac = tmpdir / "hmac.py"
+        p_hmac.write("'Docstring'\nimport completely_unknown\n")
+
+        # Appending a colon to PYTHONPATH should not break path stripping
+        # https://github.com/PyCQA/pylint/issues/3636
+        with tmpdir.as_cwd():
+            orig_pythonpath = os.environ.get("PYTHONPATH")
+            os.environ["PYTHONPATH"] = f"{(orig_pythonpath or '').strip(':')}:"
+            subprocess.check_output(
+                [
+                    sys.executable,
+                    "-m",
+                    "pylint",
+                    "astroid.py",
+                    "--disable=import-error,unused-import",
+                ],
+                cwd=str(tmpdir),
+            )
+            if orig_pythonpath:
+                os.environ["PYTHONPATH"] = orig_pythonpath
+            else:
+                del os.environ["PYTHONPATH"]
+
+    @staticmethod
+    def test_import_plugin_from_local_directory_if_pythonpath_cwd(tmpdir):
+        p_plugin = tmpdir / "plugin.py"
+        p_plugin.write("# Some plugin content")
+
+        with tmpdir.as_cwd():
+            orig_pythonpath = os.environ.get("PYTHONPATH")
+            if sys.platform == "win32":
+                os.environ["PYTHONPATH"] = "."
+            else:
+                os.environ["PYTHONPATH"] = f"{(orig_pythonpath or '').strip(':')}:."
+            process = subprocess.run(
+                [
+                    sys.executable,
+                    "-m",
+                    "pylint",
+                    "--load-plugins",
+                    "plugin",
+                ],
+                cwd=str(tmpdir),
+                stderr=subprocess.PIPE,
+                check=False,
+            )
+            assert (
+                "AttributeError: module 'plugin' has no attribute 'register'"
+                in process.stderr.decode()
+            )
+            if orig_pythonpath:
+                os.environ["PYTHONPATH"] = orig_pythonpath
+            else:
+                del os.environ["PYTHONPATH"]
+
     def test_allow_import_of_files_found_in_modules_during_parallel_check(self, tmpdir):
         test_directory = tmpdir / "test_directory"
         test_directory.mkdir()
@@ -818,3 +1049,82 @@ class TestRunTC:
             HERE, "regrtest_data", "regression_missing_init_3564", "subdirectory/"
         )
         self._test_output([path, "-j2"], expected_output="No such file or directory")
+
+    def test_output_file_valid_path(self, tmpdir):
+        path = join(HERE, "regrtest_data", "unused_variable.py")
+        output_file = tmpdir / "output.txt"
+        expected = "Your code has been rated at 7.50/10"
+        self._test_output_file(
+            [path, f"--output={output_file}"],
+            output_file,
+            expected_output=expected,
+        )
+
+    def test_output_file_invalid_path_exits_with_code_32(self):
+        path = join(HERE, "regrtest_data", "unused_variable.py")
+        output_file = "thisdirectorydoesnotexit/output.txt"
+        self._runtest([path, f"--output={output_file}"], code=32)
+
+    @pytest.mark.parametrize(
+        "output_format, expected_output",
+        [
+            (
+                "text",
+                "tests/regrtest_data/unused_variable.py:4:4: W0612: Unused variable 'variable' (unused-variable)",
+            ),
+            (
+                "parseable",
+                "tests/regrtest_data/unused_variable.py:4: [W0612(unused-variable), test] Unused variable 'variable'",
+            ),
+            (
+                "msvs",
+                "tests/regrtest_data/unused_variable.py(4): [W0612(unused-variable)test] Unused variable 'variable'",
+            ),
+            (
+                "colorized",
+                "tests/regrtest_data/unused_variable.py:4:4: W0612: [35mUnused variable 'variable'[0m ([35munused-variable[0m)",
+            ),
+            ("json", '"message": "Unused variable \'variable\'",'),
+        ],
+    )
+    def test_output_file_can_be_combined_with_output_format_option(
+        self, tmpdir, output_format, expected_output
+    ):
+        path = join(HERE, "regrtest_data", "unused_variable.py")
+        output_file = tmpdir / "output.txt"
+        self._test_output_file(
+            [path, f"--output={output_file}", f"--output-format={output_format}"],
+            output_file,
+            expected_output,
+        )
+
+    def test_output_file_can_be_combined_with_custom_reporter(self, tmpdir):
+        path = join(HERE, "regrtest_data", "unused_variable.py")
+        output_file = tmpdir / "output.txt"
+        # It does not really have to be a truly custom reporter.
+        # It is only important that it is being passed explicitly to ``Run``.
+        myreporter = TextReporter()
+        self._run_pylint(
+            [path, f"--output={output_file}"],
+            out=sys.stdout,
+            reporter=myreporter,
+        )
+        assert output_file.exists()
+
+    def test_output_file_specified_in_rcfile(self, tmpdir):
+        output_file = tmpdir / "output.txt"
+        rcfile = tmpdir / "pylintrc"
+        rcfile_contents = textwrap.dedent(
+            f"""
+        [MASTER]
+        output={output_file}
+        """
+        )
+        rcfile.write_text(rcfile_contents, encoding="utf-8")
+        path = join(HERE, "regrtest_data", "unused_variable.py")
+        expected = "Your code has been rated at 7.50/10"
+        self._test_output_file(
+            [path, f"--output={output_file}", f"--rcfile={rcfile}"],
+            output_file,
+            expected_output=expected,
+        )
